"use client";

import { useEffect, useState } from 'react';
import Link from 'next/link';
import { FaStar, FaTrashAlt } from 'react-icons/fa';
import { motion, AnimatePresence } from 'framer-motion';
import AdSense from '@/app/components/AdSense';

interface MediaItem {
  id: number;
  title: string;
  media_type: 'movie' | 'tv' | 'youtube'; // Added 'youtube'
  poster_path: string | null;
  vote_average: number | null;
  country?: string; // Added country property
}

const MyListPage = () => {
  const [myList, setMyList] = useState<MediaItem[]>([]);

  useEffect(() => {
    const storedList = JSON.parse(localStorage.getItem('myList') || '[]');
    const fetchItems = async () => {
      const items: MediaItem[] = await Promise.all(
        storedList.reverse().map(async (item: { id: string, media_type: string, title: string }) => {
          if (item.media_type === 'youtube') {
            try {
              const response = await fetch('/data/african.json');
              const data = await response.json();
              const foundMovie = data.find((movie: MediaItem) => movie.id === Number(item.id));
              return {
                id: item.id,
                title: item.title,
                media_type: 'youtube',
                country: foundMovie?.country,
              };
            } catch (error) {
              console.error('Failed to fetch YouTube item details:', error);
              return null;
            }
          } else {
            try {
              const mediaType = item.media_type;
              const response = await fetch(
                `https://api.themoviedb.org/3/${mediaType}/${item.id}?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
              );
              const data = await response.json();

              if (!data.id) {
                console.error(`No data found for ID: ${item.id}`);
                return null;
              }

              return {
                id: data.id,
                title: data.title || data.name,
                media_type: mediaType,
                poster_path: data.poster_path,
                vote_average: data.vote_average,
              };
            } catch (error) {
              console.error(`Failed to fetch details for ID: ${item.id}`, error);
              return null;
            }
          }
        })
      );

      setMyList(items.filter((item) => item !== null));
    };

    fetchItems();
  }, []);

  const handleRemove = (id: string, media_type: string) => {
    const numericId = media_type === 'youtube' ? id : Number(id);
    setMyList((prevList) => {
      const updatedList = prevList.filter((item) => item.id !== numericId);
      localStorage.setItem('myList', JSON.stringify(updatedList.map((item) => ({ id: item.id, media_type: item.media_type, title: item.title }))));
      return updatedList;
    });
  };

  return (
    <div className="p-4">
      <h1 className="text-3xl font-bold text-center mb-8 text-white mt-8 md:mt-20">My List</h1>
      {myList.length > 0 ? (
        <div className="grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4">
          <AnimatePresence>
            {myList.map((item, index) => {
              const isYouTube = item.media_type === 'youtube';
              const numericId = isYouTube ? item.id : Number(item.id);
              const slug = `${item.id}-${item.title}`.replace(/ /g, '-').replace(/[^\w-]+/g, '');
              const url = isYouTube ? `/watch/afriq/?videoId=${slug}` : item.media_type === 'movie' ? `/watch/movie/?slug=${slug}` : `/watch/tv/?slug=${slug}`;

              return (
                <motion.div
                  key={item.id}
                  className="relative"
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  exit={{ opacity: 0, y: 50, rotateX: 90 }}
                  transition={{ duration: 0.5, delay: index * 0.1 }}
                >
                  <Link href={url} passHref>
                    <div className="relative cursor-pointer animate-filter group">
                      {isYouTube ? (
                        <>
                          <div className="absolute inset-0 w-full h-full rounded-lg overflow-hidden">
                            <img
                              src={`https://img.youtube.com/vi/${item.id}/hqdefault.jpg`}
                              alt={item.title}
                              className="w-full h-full object-cover filter blur-md transform scale-150"
                            />
                          </div>
                          <div className="relative z-10 flex justify-center items-center h-[180px] md:h-[280px]">
                            <img
                              src={`https://img.youtube.com/vi/${item.id}/hqdefault.jpg`}
                              alt={item.title}
                              className="max-w-full max-h-full object-contain rounded-lg shadow-lg transition-transform duration-300 ease-in-out transform group-hover:scale-105"
                            />
                          </div>
                        </>
                      ) : (
                        <img
                          src={`https://image.tmdb.org/t/p/w500${item.poster_path}`}
                          alt={item.title}
                          className="w-full h-full object-cover rounded-lg"
                        />
                      )}
                      <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-xs px-2 py-1 rounded flex items-center z-20">
                        {isYouTube ? (
                          <>
                            <img
                              src={`/flags/${item.country?.toLowerCase()}.png`}
                              alt={item.country}
                              className="w-6 h-4 mr-2"
                            />
                            {item.country}
                          </>
                        ) : (
                          <>
                            <FaStar className="mr-1" />
                            {item.vote_average ? item.vote_average.toFixed(1) : 'N/A'}
                          </>
                        )}
                      </div>
                    </div>
                  </Link>
                  <motion.button
                    onClick={(e) => {
                      e.stopPropagation();
                      handleRemove(item.id.toString(), item.media_type);
                    }}
                    className="absolute bottom-2 right-2 bg-red-600 text-white p-2 rounded-full shadow-lg hover:bg-red-700 transition duration-300 z-30"
                    whileHover={{ scale: 1.1 }}
                    whileTap={{ scale: 0.9 }}
                    exit={{ opacity: 0, y: 50, rotateX: 90, transition: { duration: 0.5 } }}
                  >
                    <FaTrashAlt />
                  </motion.button>
                </motion.div>
              );
            })}
          </AnimatePresence>
        </div>
      ) : (
        <div className="flex flex-col items-center justify-center mt-20">
          <motion.div
            className="text-6xl"
            initial={{ scale: 1 }}
            animate={{ scale: 1.1 }}
            transition={{ repeat: Infinity, repeatType: 'reverse', duration: 0.3, delay: 5 }}
          >
            😊
          </motion.div>
          <p className="text-white text-lg mt-4">Your List is Empty</p>
          <div className="w-full my-4">
            <AdSense />
          </div>
        </div>
      )}
    </div>
  );
};

export default MyListPage;
